<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * WooCommerceProductsList starts here. Manager sets mode, adds required wp hooks and loads required object of structure
 *
 * Manager controls and access to all modules and classes of WooCommerceProductsList.
 *
 * @package WooCommerceProductsList
 * @since   1.0
 */
class WooCommerceProductsBlock {

	/**
	 * Constructor loads API functions, defines paths and adds required wp actions
	 *
	 * @since  1.0
	 */
	public function __construct() 
	{
		add_action( 'init', array( $this, 'init' ), 9 );
	}

	/**
	 * Callback function for WP init action hook. Sets WooCommerceProductsList mode and loads required objects.
	 *
	 * @since  1.0
	 * @access public
	 *
	 * @return void
	 */
	public function init() 
	{
		do_action( 'WooCommerceProductsBlock_before_init' );
		
		global $wpdb;
		$this->db = $wpdb;

		add_action('wp_ajax_WZPBajaxRequest', array( $this, 'WZPBajaxRequest') );
		add_action('wp_ajax_nopriv_WZPBajaxRequest', array( $this, 'WZPBajaxRequest') );

		if( is_admin() ){
			$this->editor_assets();
		}else{
			$this->frontend_assets();
		}

		do_action( 'WooCommerceProductsBlock_after_init' );
	}

	public function frontend_assets()
	{
		wp_enqueue_style(
			'WZPB-view',
			plugins_url( 'frontend/frontend.view.css', __FILE__ ),
			array( 'wp-edit-blocks' )
		);

		wp_enqueue_style(
			'WZPB-custom-font',
			plugins_url( '../assets/fonts/iconmoon.css', __FILE__ ),
			array( 'wp-edit-blocks' )
		);

		wp_enqueue_style( 'dashicons' );
		
		wp_enqueue_script(
			'WZPB-view',
			plugins_url( 'frontend/frontend.build.js', __FILE__ )
	  	);

	  	wp_localize_script( 'WZPB-view', 'WZPB', array(
	  		'ajax_url' => admin_url('admin-ajax.php?action=WZPBajaxRequest'),
			'assets_url' => WOOCOMMERCE_PRODUCTS_BLOCK_URL,
			'google_fonts' => array()
		) );
	}
	
	public function editor_assets()
	{
		wp_enqueue_style( 'dashicons' );

		wp_enqueue_script(
			'WZPB',
			plugins_url( 'backend/backend.build.js', __FILE__ ),
			array( 'wp-blocks', 'wp-element', 'wp-editor' )
	  	);

	  	wp_enqueue_style(
			'WZPB-custom-font',
			plugins_url( '../assets/fonts/iconmoon.css', __FILE__ ),
			array( 'wp-edit-blocks' )
		);

		wp_enqueue_style(
			'WZPB-editor',
			plugins_url( 'backend/backend.editor.css', __FILE__ ),
			array( 'wp-edit-blocks' )
		);
		
		wp_enqueue_style(
			'WZPB-view',
			plugins_url( 'frontend/frontend.view.css', __FILE__ ),
			array( 'wp-edit-blocks' )
		);

		wp_localize_script( 'WZPB', 'WZPB', array(
			'ajax_url' => admin_url('admin-ajax.php?action=WZPBajaxRequest'),
			'assets_url' => WOOCOMMERCE_PRODUCTS_BLOCK_URL,
			'google_fonts' => array()
		) );
	}

	public function WZPBajaxRequest()
	{
		$action = isset($_REQUEST['sub_action']) && in_array($_REQUEST['sub_action'], array('get_products')) ? $_REQUEST['sub_action'] : null;
		$params = isset($_REQUEST['params']) && $_REQUEST['params'] != '' ? $_REQUEST['params'] : null;
		
		if( $action ) {
			if( $action == 'get_products' ) $this->getProducts( $params );
		}
	}

	public function getProducts( $params = array() )
	{
		$get_args = array(
			'status' => 'publish',
			'limit' => -1,
		);

		if( isset($params) && count($params) > 0 ) {
			$get_args['include'] = explode(',', $params);
		}

		if( class_exists('WooZone') ) {
			$woozone_options = get_option('WooZone_amazon');
			$amz_aff_ids = $woozone_options['AffiliateID'];
		}

		$products = wc_get_products($get_args);
		
		$woo_products = array();
		foreach( $products as $product ) {
			$pID = $product->get_ID();

			$regular_price = $product->get_regular_price();
			$sale_price = $product->get_sale_price();
			$amz_url = '';
			$amz_country = '';
			$amz_aff_id = '';
			$amz_ASIN = '';

			// get gallery images (if any)
			$gallery_img_urls = array();
			$attach_ids = $product->get_gallery_attachment_ids();
			if( is_array($attach_ids) && count($attach_ids) > 0 ) {
				foreach ($attach_ids as $attach_id ) {
					$gallery_img_urls[] = wp_get_attachment_url( $attach_id );
				}
			}

			$amzaff_pType = get_post_meta($pID, '_amzaff_prodtype', true);
			if( $amzaff_pType == 'amazon' ) {
				$amz_is_prime = get_post_meta($pID, '_amzaff_isAmazonPrime', true);
				$amz_country = get_post_meta($pID, '_amzaff_country', true);
				$amz_url = get_post_meta($pID, '_amzaff_product_url', true);
				$amz_country = get_post_meta($pID, '_amzaff_country', true);
				$amz_aff_id = $amz_aff_ids[$amz_country];
				$amz_ASIN = get_post_meta($pID, '_amzASIN', true);
			}
			
			$woo_products[] = array(
				'id' => $pID,
				'title' => $product->get_title(),
				'excerpt' => apply_filters( 'the_excerpt', get_the_excerpt( $pID ) ),
				'price' => $product->get_price(),
				'img' => $product->get_image(),
				'additional_imgs' => $gallery_img_urls,
				'url' => $product->get_permalink(),
				'amz_url' => isset($amz_url) && $amz_url != '' ? $amz_url : '',
				'IsPrimeEligible' => $amz_is_prime > 0 ? $amz_is_prime : 0,
				'category' => $product->get_categories( ', ', '', '' ),
				'price' => $regular_price != 0 ? wc_price($regular_price) : '',
				'sale_price' => $sale_price != 0 ? wc_price($sale_price) : '',
				'amz_country' => $amz_country,
				'amz_aff_id' => $amz_aff_id,
				'amz_ASIN' => $amz_ASIN
			);
		}

		die( json_encode( $woo_products ) );
	}
}

/**
 * Main WooCommerceProductsList manager.
 * @var WooCommerceProductsList $WooCommerceProductsList - instance of composer management.
 * @since 1.0
 */
global $WooCommerceProductsBlock;
$WooCommerceProductsBlock = new WooCommerceProductsBlock();

function WooCommerceProductsBlock(){
	global $WooCommerceProductsBlock;

	return $WooCommerceProductsBlock;
}