const path = require('path');
const ExtractTextPlugin = require("extract-text-webpack-plugin");
var BrowserSyncPlugin = require('browser-sync-webpack-plugin')

const glob = require('glob');

// different instances for editor or view css files
const viewExtractTextPlugin = new ExtractTextPlugin("[name]/[name].view.css");

const nodeExternals = require('webpack-node-externals');

module.exports = [{
    entry: function () {
        /*
        function to map globs to appropriate entries for separate build files
        object that is returned looks like:
          {
              block-name: 'src/block-name/block-name.js',
              ...
          }
        */
        let entriesObject = {}

        glob.sync("./src/**/*.view.js").map((el) => {
            let path = el;
            let name = el.split('/').pop().split('.')[0];
            entriesObject[name] = path;
        })

        return entriesObject;
    },
    
    output: {
        path: path.resolve(__dirname, 'blocks'),
        filename: '[name]/[name].view.js'
    },

    module: {
        rules: [
            {
                test: /\.view.scss$/,
                use: viewExtractTextPlugin.extract({
                    use: [{
                        loader: 'css-loader'
                    }, {
                        loader: 'sass-loader'
                    }],
                    fallback: 'style-loader'
                })
            },
            {
                test: /\.css$/,
                loaders: ['style-loader', 'css-loader'],
            },
            
            {
                test: /\.jsx?$/,
                exclude: /node_modules/,
                use: [
                  {
                    loader: 'babel-loader',
                    options: {
                      presets: ["es2015","react","stage-3", "env"]
                    }
                  }
                ],
            },
            {
                test: /\.woff2?$|\.ttf$|\.eot$|\.svg$/,
                use: ['url-loader']
            }
        ]
    },

    plugins: [
        viewExtractTextPlugin,
        new BrowserSyncPlugin({
            host: '192.168.1.2',
            port: 3043,
            proxy: 'http://dev.aa-team.com/test/victor_multisite/woocommerce-products-block/'
        })
    ],

    stats: {
        colors: true
    },
    devtool: 'source-map'
}];